==> SetMethods_1.0.tar.gz: SetMethods/man/LipsetFS.Rd <==
\name{LipsetFS}
\alias{LipsetFS}
\docType{data}
\title{Lipset (1959), fuzzy-set}
\description{The \code{LipsetFS} data frame has 18 rows and 6 variables}

\usage{data(LipsetFS)}
\format{
  A data frame with 18 observations on the following 6 variables.
  \describe{
    \item{\code{Survived}}{a numeric vector. Outcome, survival of democracy during the inter-war period.}
    \item{\code{DEVELOPED}}{a numeric vector. Condition, economically developed countries.}
    \item{\code{URBAN}}{a numeric vector. Condition, urbanized countries.}
    \item{\code{LITERATE}}{a numeric vector. Condition, countries with high literacy rate.}
    \item{\code{INDUSTRIAL}}{a numeric vector. Condition, industrialized countries.}
    \item{\code{STABLE}}{a numeric vector. Condition, politically stable countries.}
  }
}
\details{Data used by Ragin (2009) to illustrates the variants of QCA. Originally by Lipset (1959). Data are fuzzy-sets.}
\references{
Lipset, S. M. (1959) "Some Social Requisites of Democracy: Economic Development and Political Legitimacy", American Political Science Review 53, pp. 69-105.

Ragin, C. C. (2009) "Qualitative Comparative Analysis. Using Fuzzy Sets (fsQCA)." In Rihoux, B., and Ragin, C. C. (eds.) Configurational Comparative Methods. Qualitative Comparative Analysis (QCA) and Related Techniques. Thousand Oaks, CA and London: Sage, pp. 87-121.

Schneider, C. Q., Wagemann, C. (2012) Set-Theoretic Methods for the Social Sciences, Cambridge University Press: Cambridge.

Schneider, C. Q., Wagemann, C., Quaranta, M. (2012) How To... Use Software for Set-Theoretic Analysis. Online Appendix to "Set-Theoretic Methods for the Social Sciences". Available at \url{www.cambridge.org/schneider-wagemann}.
}
\examples{data(LipsetFS)}
\keyword{datasets}

==> SetMethods_2.1.tar.gz: SetMethods/man/LipsetFS.Rd <==
\name{LipsetFS}
\alias{LipsetFS}
\docType{data}
\title{Lipset (1959), fuzzy-set}
\description{The \code{LipsetFS} data frame has 18 rows and 6 sets}

\usage{data(LipsetFS)}
\format{
  A data frame with 18 observations on the following 6 sets.
  \describe{
    \item{\code{Survived}}{a numeric vector. Outcome, survival of democracy during the inter-war period.}
    \item{\code{DEVELOPED}}{a numeric vector. Condition, economically developed countries.}
    \item{\code{URBAN}}{a numeric vector. Condition, urbanized countries.}
    \item{\code{LITERATE}}{a numeric vector. Condition, countries with high literacy rate.}
    \item{\code{INDUSTRIAL}}{a numeric vector. Condition, industrialized countries.}
    \item{\code{STABLE}}{a numeric vector. Condition, politically stable countries.}
  }
}
\details{Data used by Ragin (2009) to illustrates the variants of QCA. Originally by Lipset (1959). Data are fuzzy-sets.}
\references{
Lipset, S. M. (1959) "Some Social Requisites of Democracy: Economic Development and Political Legitimacy", American Political Science Review 53, pp. 69-105.

Ragin, C. C. (2009) "Qualitative Comparative Analysis. Using Fuzzy Sets (fsQCA)." In Rihoux, B., and Ragin, C. C. (eds.) Configurational Comparative Methods. Qualitative Comparative Analysis (QCA) and Related Techniques. Thousand Oaks, CA and London: Sage, pp. 87-121.

Schneider, C. Q., Wagemann, C. (2012) Set-Theoretic Methods for the Social Sciences, Cambridge University Press: Cambridge.

Schneider, C. Q., Wagemann, C., Quaranta, M. (2012) How To... Use Software for Set-Theoretic Analysis. Online Appendix to "Set-Theoretic Methods for the Social Sciences". Available at \url{www.cambridge.org/schneider-wagemann}.
}
\examples{data(LipsetFS)}
\keyword{datasets}
